WaitForError

Enum WaitForError 

#[non_exhaustive]
pub enum WaitForError { Poll { error: PollError, elapsed: Duration, }, MissingParentDirectory { path: Utf8PathBuf, parent: Utf8PathBuf, elapsed: Duration, }, ParentNotADirectory { path: Utf8PathBuf, parent: Utf8PathBuf, elapsed: Duration, }, TimedOut { path: Utf8PathBuf, elapsed: Duration, }, }
A permanent error returned by wait_for and wait_for_blocking.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Poll

A poll operation returned a permanent error.

Fields

error: PollError

The error that occurred.

elapsed: Duration

How long the driver had been waiting when the error occurred.



MissingParentDirectory

The parent directory of the port file does not exist.

Fields

path: Utf8PathBuf

The path to the port file.

parent: Utf8PathBuf

The parent directory that does not exist.

elapsed: Duration

How long the driver had been waiting when the error occurred.



ParentNotADirectory

The parent path of the port file exists but is not a directory.

This is most likely to occur on Windows. On Unix-like platforms, this condition usually surfaces as WaitForError::Poll with PollError::Io instead, because reading the port file itself fails with a “not a directory” error.

Fields

path: Utf8PathBuf

The path to the port file.

parent: Utf8PathBuf

The parent path that is not a directory.

elapsed: Duration

How long the driver had been waiting when the error occurred.



TimedOut

The timeout was reached.

Fields

path: Utf8PathBuf

The path of the port file that was being waited for.

elapsed: Duration

How long the driver had been waiting when the error occurred.

Implementations

Source

impl WaitForError

pub fn path(&self) -> &Utf8Path

Returns the path of the port file that was being waited for.

pub fn elapsed(&self) -> Duration

Returns how long the driver had been waiting when the error occurred.