pub struct PollInterval(pub Duration);Expand description
How long wait_for and wait_for_blocking sleep between polls of the
port file.
A typical value for the poll interval is 25 milliseconds.
Sleeps are clamped to the time remaining before the Timeout deadline, so
a long poll interval does not end up in the wait functions waiting past the
deadline.
This is a newtype (rather than a bare Duration) so it cannot be
confused with Timeout.
Tuple Fields
0: DurationTrait Implementations
Sourceimpl Clone for PollInterval
impl Clone for PollInterval
Sourcefn clone(&self) -> PollInterval
fn clone(&self) -> PollInterval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PollInterval
Sourceimpl Debug for PollInterval
impl Debug for PollInterval
impl Eq for PollInterval
Sourceimpl PartialEq for PollInterval
impl PartialEq for PollInterval
Sourcefn eq(&self, other: &PollInterval) -> bool
fn eq(&self, other: &PollInterval) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PollInterval