pub struct Timeout(pub Duration);Expand description
How long wait_for and wait_for_blocking keep polling before giving
up.
A typical value for the timeout is 30 seconds.
Note that the wait functions poll for the port file at least once even with a zero timeout, and poll one final time once the deadline passes. This means that a file appearing before the deadline is always found. (A zero timeout acts as a single non-blocking check.)
This is a newtype (rather than a bare Duration) so it cannot be
confused with PollInterval.
Tuple Fields
0: DurationTrait Implementations
impl Copy for Timeout
impl Eq for Timeout
impl StructuralPartialEq for Timeout