#[non_exhaustive]pub enum WaitForError {
Poll {
error: PollError,
elapsed: Duration,
},
MissingParentDirectory {
path: Utf8PathBuf,
parent: Utf8PathBuf,
elapsed: Duration,
},
ParentNotADirectory {
path: Utf8PathBuf,
parent: Utf8PathBuf,
elapsed: Duration,
},
TimedOut {
path: Utf8PathBuf,
elapsed: Duration,
},
}Expand description
A permanent error returned by wait_for and wait_for_blocking.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Poll
A poll operation returned a permanent error.
Fields
MissingParentDirectory
The parent directory of the port file does not exist.
Fields

path: Utf8PathBufThe path to the port file.

parent: Utf8PathBufThe parent directory that does not exist.
ParentNotADirectory
The parent path of the port file exists but is not a directory.
This is most likely to occur on Windows. On Unix-like platforms, this
condition usually surfaces as WaitForError::Poll with
PollError::Io instead, because reading the port file itself fails
with a “not a directory” error.
Fields

path: Utf8PathBufThe path to the port file.

parent: Utf8PathBufThe parent path that is not a directory.
TimedOut
The timeout was reached.
Fields

path: Utf8PathBufThe path of the port file that was being waited for.
Implementations